@@ -1,6 +1,6 @@
 /*
   Racket
-  Copyright (c) 2004-2015 PLT Design Inc.
+  Copyright (c) 2004-2018 PLT Design Inc.
   Copyright (c) 1995-2001 Matthew Flatt
   All rights reserved.
 
@@ -49,14 +49,12 @@
 #ifdef MZ_PRECISE_GC
 # define MUST_REGISTER_GLOBALS
 # define MZTAG_REQUIRED
-# undef UNIX_IMAGE_DUMPS
 /* In case SGC is used to build PRECISE_GC: */
 # undef USE_SENORA_GC
 #endif
 
 #ifdef USE_SENORA_GC
 # define MUST_REGISTER_GLOBALS
-# undef UNIX_IMAGE_DUMPS
 #endif
 
 #ifdef USE_SINGLE_FLOATS
@@ -93,6 +91,9 @@ typedef struct {
 typedef long double mz_long_double;
 # endif
 #else
+# ifdef MZ_INSIST_EXTFLONUMS
+#  error "cannot support extflonums; you may need to adjust compiler options"
+# endif
 typedef double mz_long_double;
 #endif
 
@@ -150,12 +151,6 @@ typedef long FILE;
 # define MSCBOR_IZE(x) MSC_IZE(x)
 #endif
 
-#ifdef SIGSET_IS_SIGNAL
-# define MZ_SIGSET(s, f) signal(s, f)
-#else
-# define MZ_SIGSET(s, f) sigset(s, f)
-#endif
-
 /* C99 allows an array in a struct to be declared
    with [] to indicate that its actual size can be
    any number. The old way was to declare the array
@@ -174,9 +169,19 @@ typedef long FILE;
 #endif
 
 #ifdef MZ_XFORM
+/* A non-GCing function will never trigger a garbage collection.
+   The xform tool checks this declaration, and it uses this hint
+   to avoid registering variables unnecessarily. */
 # define XFORM_NONGCING __xform_nongcing__
+/* A non-GCing, non-aliasing function is non-GCing, and it may take
+   arguments that are addresses of local variables, but it doesn't
+   leak those addresses; it only filles them in. The xform tool only
+   checks the non-GCing part of this declaration, but uses both
+   facets of the hint. */
+# define XFORM_NONGCING_NONALIASING __xform_nongcing_nonaliasing__
 #else
 # define XFORM_NONGCING /* empty */
+# define XFORM_NONGCING_NONALIASING /* empty */
 #endif
 
 #ifdef MZ_XFORM
@@ -200,12 +205,6 @@ typedef jmpbuf jmp_buf[1];
 
 #define GC_MIGHT_USE_REGISTERED_STATICS
 
-#ifdef MACINTOSH_EVENTS
-/* We avoid #including the Carbon headers because we only
-   need a few abstract struct types: */
-typedef struct FSSpec mzFSSpec;
-#endif
-
 #ifndef MZ_DONT_USE_JIT
 # if defined(MZ_USE_JIT_PPC) || defined(MZ_USE_JIT_I386) || defined(MZ_USE_JIT_X86_64) || defined(MZ_USE_JIT_ARM)
 #  define MZ_USE_JIT
@@ -224,6 +223,7 @@ typedef struct FSSpec mzFSSpec;
 #ifdef MZ_PRECISE_GC
 # ifndef MZ_XFORM
 #  define XFORM_SKIP_PROC /* empty */
+#  define XFORM_ASSERT_NO_CONVERSION /* empty */
 #  define XFORM_CAN_IGNORE /**/
 # endif
 #else
@@ -233,6 +233,7 @@ typedef struct FSSpec mzFSSpec;
 # define XFORM_START_SUSPEND /**/
 # define XFORM_END_SUSPEND /**/
 # define XFORM_SKIP_PROC /**/
+#  define XFORM_ASSERT_NO_CONVERSION /**/
 # define XFORM_START_TRUST_ARITH /**/
 # define XFORM_END_TRUST_ARITH /**/
 # define XFORM_CAN_IGNORE /**/
@@ -511,7 +512,7 @@ typedef intptr_t (*Scheme_Secondary_Hash_Proc)(Scheme_Object *obj, void *cycle_d
 #define SCHEME_PAIRP(obj)    SAME_TYPE(SCHEME_TYPE(obj), scheme_pair_type)
 #define SCHEME_MPAIRP(obj)    SAME_TYPE(SCHEME_TYPE(obj), scheme_mutable_pair_type)
 #define SCHEME_MUTABLE_PAIRP(obj)    SCHEME_MPAIRP(obj)
-#define SCHEME_LISTP(obj)    (SCHEME_NULLP(obj) || SCHEME_PAIRP(obj))
+#define SCHEME_LISTP(obj)    scheme_is_list(obj)
 
 #define SCHEME_RPAIRP(obj)    SAME_TYPE(SCHEME_TYPE(obj), scheme_raw_pair_type)
 
@@ -697,7 +698,7 @@ typedef struct Scheme_Offset_Cptr
 /*               fast basic Scheme constructor macros                     */
 /*========================================================================*/
 
-#define scheme_make_integer(i)    LONG_TO_OBJ ((OBJ_TO_LONG(i) << 1) | 0x1)
+#define scheme_make_integer(i)    LONG_TO_OBJ ((((uintptr_t)OBJ_TO_LONG(i)) << 1) | 0x1)
 #define scheme_make_character(ch) ((((mzchar)ch) < 256) ? scheme_char_constants[(unsigned char)(ch)] : scheme_make_char(ch))
 #define scheme_make_ascii_character(ch) scheme_char_constants[(unsigned char)(ch)]
 
@@ -742,10 +743,9 @@ typedef struct Scheme_Offset_Cptr
 #define SCHEME_PRIM_IS_MULTI_RESULT 8
 #define SCHEME_PRIM_IS_CLOSURE 16
 #define SCHEME_PRIM_OTHER_TYPE_MASK (32 | 64 | 128 | 256)
-#define SCHEME_PRIM_IS_METHOD 512
 
-#define SCHEME_PRIM_OPT_INDEX_SIZE 6
-#define SCHEME_PRIM_OPT_INDEX_SHIFT 10
+#define SCHEME_PRIM_OPT_INDEX_SIZE 7
+#define SCHEME_PRIM_OPT_INDEX_SHIFT 9
 #define SCHEME_PRIM_OPT_INDEX_MASK ((1 << SCHEME_PRIM_OPT_INDEX_SIZE) - 1)
 
 /* Values with SCHEME_PRIM_OPT_MASK, earlier implies later: */
@@ -880,7 +880,7 @@ typedef struct {
 /* ------------------------------------------------- */
 
 #define SCHEME_PROCP(obj)  (!SCHEME_INTP(obj) && ((_SCHEME_TYPE(obj) >= scheme_prim_type) && (_SCHEME_TYPE(obj) <= scheme_proc_chaperone_type)))
-#define SCHEME_SYNTAXP(obj)  SAME_TYPE(SCHEME_TYPE(obj), scheme_syntax_compiler_type)
+#define SCHEME_SYNTAXP(obj)  SAME_TYPE(SCHEME_TYPE(obj), scheme_primitive_syntax_type)
 #define SCHEME_PRIMP(obj)    SAME_TYPE(SCHEME_TYPE(obj), scheme_prim_type)
 #define SCHEME_CLSD_PRIMP(obj)    SAME_TYPE(SCHEME_TYPE(obj), scheme_closed_prim_type)
 #define SCHEME_CONTP(obj)    SAME_TYPE(SCHEME_TYPE(obj), scheme_cont_type)
@@ -892,8 +892,8 @@ typedef struct {
 #define SCHEME_PRIM(obj)     (((Scheme_Primitive_Proc *)(obj))->prim_val)
 #define SCHEME_CLSD_PRIM(obj) (((Scheme_Closed_Primitive_Proc *)(obj))->prim_val)
 #define SCHEME_CLSD_PRIM_DATA(obj) (((Scheme_Closed_Primitive_Proc *)(obj))->data)
-#define SCHEME_CLOS_FUNC(obj) ((Scheme_Closure_Func)SCHEME_CAR(obj))
-#define SCHEME_CLOS_DATA(obj) SCHEME_CDR(obj)
+#define SCHEME_RAW_CLOS_FUNC(obj) ((Scheme_Closure_Func)SCHEME_CAR(obj))
+#define SCHEME_RAW_CLOS_DATA(obj) SCHEME_CDR(obj)
 
 /*========================================================================*/
 /*                      hash tables and environments                      */
@@ -942,6 +942,12 @@ enum {
   SCHEME_hash_late_weak_ptr
 };
 
+enum {
+  SCHEME_hashtr_eq,
+  SCHEME_hashtr_equal,
+  SCHEME_hashtr_eqv
+};
+
 typedef struct Scheme_Env Scheme_Env;
 
 #define SCHEME_VAR_BUCKET(obj) ((Scheme_Bucket *)(obj))
@@ -1345,6 +1351,7 @@ enum {
   MZCONFIG_CAN_READ_READER,
   MZCONFIG_CAN_READ_LANG,
   MZCONFIG_READ_DECIMAL_INEXACT,
+  MZCONFIG_READ_CDOT,
   
   MZCONFIG_PRINT_GRAPH,
   MZCONFIG_PRINT_STRUCT,
@@ -1362,6 +1369,8 @@ enum {
   MZCONFIG_CASE_SENS,
   MZCONFIG_SQUARE_BRACKETS_ARE_PARENS,
   MZCONFIG_CURLY_BRACES_ARE_PARENS,
+  MZCONFIG_SQUARE_BRACKETS_ARE_TAGGED,
+  MZCONFIG_CURLY_BRACES_ARE_TAGGED,
 
   MZCONFIG_ERROR_PRINT_WIDTH,
   MZCONFIG_ERROR_PRINT_CONTEXT_LENGTH,
@@ -1384,6 +1393,7 @@ enum {
   MZCONFIG_USE_COMPILED_ROOTS,
   MZCONFIG_USE_USER_PATHS,
   MZCONFIG_USE_LINK_PATHS,
+  MZCONFIG_USE_COMPILED_FILE_CHECK,
 
   MZCONFIG_LOAD_DIRECTORY,
   MZCONFIG_WRITE_DIRECTORY,
@@ -1519,6 +1529,8 @@ struct Scheme_Input_Port
 #endif
 };
 
+#define SCHEME_INPORT_VAL(i) (((Scheme_Input_Port *)i)->port_data)
+
 struct Scheme_Output_Port
 {
   struct Scheme_Port p;
@@ -1542,9 +1554,7 @@ struct Scheme_Output_Port
   struct Scheme_Input_Port *input_half;
 };
 
-#define SCHEME_INPORT_VAL(obj) (((Scheme_Input_Port *)(obj))->port_data)
-#define SCHEME_OUTPORT_VAL(obj) (((Scheme_Output_Port *)(obj))->port_data)
-#define SCHEME_IPORT_NAME(obj) (((Scheme_Input_Port *)obj)->name)
+#define SCHEME_OUTPORT_VAL(o) (((Scheme_Output_Port *)o)->port_data)
 
 #define SCHEME_SPECIAL (-2)
 #define SCHEME_UNLESS_READY (-3)
@@ -1846,6 +1856,10 @@ extern void *scheme_malloc_envunbox(size_t);
 # define MZ_GC_UNREG()                   /* empty */
 #endif
 
+#define SCHEME_GC_SHAPE_TERM       0
+#define SCHEME_GC_SHAPE_PTR_OFFSET 1
+#define SCHEME_GC_SHAPE_ADD_SIZE   2
+
 /*========================================================================*/
 /*                   embedding configuration and hooks                    */
 /*========================================================================*/
@@ -1878,11 +1892,16 @@ MZ_EXTERN void scheme_set_startup_use_jit(int);
 MZ_EXTERN void scheme_set_startup_load_on_demand(int);
 MZ_EXTERN void scheme_set_ignore_user_paths(int);
 MZ_EXTERN void scheme_set_ignore_link_paths(int);
+MZ_EXTERN void scheme_set_cross_compile_mode(int);
 MZ_EXTERN void scheme_set_logging(int syslog_level, int stderr_level);
 MZ_EXTERN void scheme_set_logging_spec(Scheme_Object *syslog_level, Scheme_Object *stderr_level);
 
 MZ_EXTERN int scheme_get_allow_set_undefined();
 
+MZ_EXTERN void scheme_set_compiled_file_check(int);
+#define SCHEME_COMPILED_FILE_CHECK_MODIFY_SECONDS 0  
+#define SCHEME_COMPILED_FILE_CHECK_EXISTS         1
+
 #ifdef MZ_CAN_ACCESS_THREAD_LOCAL_DIRECTLY
 THREAD_LOCAL_DECL(MZ_EXTERN Scheme_Thread *scheme_current_thread);
 THREAD_LOCAL_DECL(MZ_EXTERN Scheme_Thread *scheme_first_thread);
@@ -1923,9 +1942,6 @@ MZ_EXTERN void (*scheme_suspend_main_thread)(void);
 int scheme_set_in_main_thread(void);
 void scheme_restore_nonmain_thread(void);
 #endif
-#ifdef MAC_FILE_SYSTEM
-extern long scheme_creator_id;
-#endif
 
 typedef Scheme_Object *(*Scheme_Stdio_Maker_Proc)(void);
 MZ_EXTERN Scheme_Object *(*scheme_make_stdin)(void);
@@ -1942,11 +1958,16 @@ MZ_EXTERN Scheme_Object *scheme_set_exec_cmd(char *s);
 MZ_EXTERN Scheme_Object *scheme_set_run_cmd(char *s);
 MZ_EXTERN void scheme_set_collects_path(Scheme_Object *p);
 MZ_EXTERN void scheme_set_config_path(Scheme_Object *p);
+MZ_EXTERN void scheme_set_host_collects_path(Scheme_Object *p);
+MZ_EXTERN void scheme_set_host_config_path(Scheme_Object *p);
 MZ_EXTERN void scheme_set_original_dir(Scheme_Object *d);
 MZ_EXTERN void scheme_set_addon_dir(Scheme_Object *p);
 MZ_EXTERN void scheme_set_command_line_arguments(Scheme_Object *vec);
 MZ_EXTERN void scheme_set_compiled_file_paths(Scheme_Object *list);
 MZ_EXTERN void scheme_set_compiled_file_roots(Scheme_Object *list);
+#ifdef DOS_FILE_SYSTEM
+MZ_EXTERN void scheme_set_dll_path(wchar_t *s);
+#endif
 
 MZ_EXTERN void scheme_init_collection_paths(Scheme_Env *global_env, Scheme_Object *extra_dirs);
 MZ_EXTERN void scheme_init_collection_paths_post(Scheme_Env *global_env, Scheme_Object *extra_dirs, Scheme_Object *extra_post_dirs);
@@ -2008,6 +2029,12 @@ MZ_EXTERN Scheme_Object *scheme_register_parameter(Scheme_Prim *function, char *
 
 #endif /* SCHEME_DIRECT_EMBEDDED */
 
+/*========================================================================*/
+/*                             OS signals                                 */
+/*========================================================================*/
+
+typedef void (*Scheme_Signal_Handler_Proc)(int);
+
 /*========================================================================*/
 /*                              addrinfo                                  */
 /*========================================================================*/
@@ -2103,34 +2130,11 @@ extern Scheme_Extension_Table *scheme_extension_table;
 /*                           file descriptors                             */
 /*========================================================================*/
 
-#if defined(DETECT_WIN32_CONSOLE_STDIN) || defined(WINDOWS_PROCESSES)
-# ifndef NO_STDIO_THREADS
-#  define USE_FAR_MZ_FDCALLS
-# endif
-#endif
-#ifdef USE_DYNAMIC_FDSET_SIZE
-# define USE_FAR_MZ_FDCALLS
-#endif
-#ifdef USE_BEOS_PORT_THREADS
-# define USE_FAR_MZ_FDCALLS
-#endif
-#ifdef HAVE_POLL_SYSCALL
-# define USE_FAR_MZ_FDCALLS
-#endif
-
-#ifdef USE_FAR_MZ_FDCALLS
 # define MZ_GET_FDSET(p, n) scheme_get_fdset(p, n)
 # define MZ_FD_ZERO(p) scheme_fdzero(p)
 # define MZ_FD_SET(n, p) scheme_fdset(p, n)
 # define MZ_FD_CLR(n, p) scheme_fdclr(p, n)
 # define MZ_FD_ISSET(n, p) scheme_fdisset(p, n)
-#else
-# define MZ_GET_FDSET(p, n) ((void *)(((fd_set *)p) XFORM_OK_PLUS n))
-# define MZ_FD_ZERO(p) XFORM_HIDE_EXPR(FD_ZERO((fd_set *)(p)))
-# define MZ_FD_SET(n, p) FD_SET(n, (fd_set *)(p))
-# define MZ_FD_CLR(n, p) FD_CLR(n, (fd_set *)(p))
-# define MZ_FD_ISSET(n, p) FD_ISSET(n, (fd_set *)(p))
-#endif
 
 /* For scheme_fd_to_semaphore(): */
 #define MZFD_CREATE_READ  1
@@ -2138,9 +2142,6 @@ extern Scheme_Extension_Table *scheme_extension_table;
 #define MZFD_CHECK_READ   3
 #define MZFD_CHECK_WRITE  4
 #define MZFD_REMOVE       5
-#define MZFD_CREATE_VNODE 6
-#define MZFD_CHECK_VNODE  7
-#define MZFD_REMOVE_VNODE 8
 
 /*========================================================================*/
 
