@@ -1,6 +1,6 @@
 /*
   Racket
-  Copyright (c) 2004-2017 PLT Design Inc.
+  Copyright (c) 2004-2018 PLT Design Inc.
   Copyright (c) 1995-2001 Matthew Flatt
   All rights reserved.
 
@@ -123,6 +123,7 @@ int (*scheme_flush_managed)(Scheme_Plumber *p, int catch_errors);
 Scheme_Object *(*scheme_add_flush)(Scheme_Plumber *p, Scheme_Object *proc_or_port, int weak_flush);
 void (*scheme_remove_flush)(Scheme_Object *h);
 void (*scheme_add_atexit_closer)(Scheme_Exit_Closer_Func f);
+int (*scheme_atexit)(void (*func)(void));
 void (*scheme_add_evt)(Scheme_Type type,
 				   Scheme_Ready_Fun ready,
 				   Scheme_Needs_Wakeup_Fun wakeup,
@@ -147,7 +148,7 @@ void (*scheme_push_break_enable)(Scheme_Cont_Frame_Data *cframe, int on, int pre
 void (*scheme_pop_break_enable)(Scheme_Cont_Frame_Data *cframe, int post_check);
 Scheme_Object *(*scheme_abort_continuation_no_dws)(Scheme_Object *pt, Scheme_Object *v);
 Scheme_Object *(*scheme_call_with_composable_no_dws)(Scheme_Object *proc, Scheme_Object *pt);
-Scheme_On_Atomic_Timeout_Proc (*scheme_set_on_atomic_timeout)(Scheme_On_Atomic_Timeout_Proc p);
+Scheme_On_Atomic_Timeout_Proc (*scheme_set_on_atomic_timeout)(Scheme_On_Atomic_Timeout_Proc p, void *data);
 /*========================================================================*/
 /*                              error handling                            */
 /*========================================================================*/
@@ -806,10 +807,6 @@ Scheme_Object *(*scheme_make_sized_path)(char *chars, intptr_t len, int copy);
 Scheme_Object *(*scheme_make_sized_offset_path)(char *chars, intptr_t d, intptr_t len, int copy);
 Scheme_Object *(*scheme_make_sized_offset_kind_path)(char *chars, intptr_t d, intptr_t len, int copy, int kind);
 Scheme_Object *(*scheme_make_path_without_copying)(char *chars);
-#ifdef MACINTOSH_EVENTS
-char *(*scheme_mac_spec_to_path)(mzFSSpec *spec);
-int (*scheme_mac_path_to_spec)(const char *filename, mzFSSpec *spec);
-#endif
 void *(*scheme_alloc_fdset_array)(int count, int permanent);
 void *(*scheme_init_fdset_array)(void *fdarray, int count);
 void *(*scheme_get_fdset)(void *fdarray, int pos);
@@ -1008,6 +1005,7 @@ Scheme_Object *(*scheme_malloc_key)(void);
 void (*scheme_free_key)(Scheme_Object *k);
 void *(*scheme_jit_find_code_end)(void *p);
 void (*scheme_jit_now)(Scheme_Object *f);
+void (*scheme_set_signal_handler)(int sig_id, Scheme_Signal_Handler_Proc proc);
 #ifndef SCHEME_EX_INLINE
 } Scheme_Extension_Table;
 #endif
